summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/drivermanager_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb/drivermanager_p.h')
-rw-r--r--kexi/kexidb/drivermanager_p.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/kexi/kexidb/drivermanager_p.h b/kexi/kexidb/drivermanager_p.h
index ce92dd03..85388270 100644
--- a/kexi/kexidb/drivermanager_p.h
+++ b/kexi/kexidb/drivermanager_p.h
@@ -22,24 +22,25 @@
#include <kexidb/object.h>
-#include <qobject.h>
-#include <qasciidict.h>
+#include <tqobject.h>
+#include <tqasciidict.h>
namespace KexiDB {
/*! Internal class of driver manager.
*/
-class KEXI_DB_EXPORT DriverManagerInternal : public QObject, public KexiDB::Object
+class KEXI_DB_EXPORT DriverManagerInternal : public TQObject, public KexiDB::Object
{
Q_OBJECT
+ TQ_OBJECT
public:
~DriverManagerInternal();
/*! Tries to load db driver \a name.
\return db driver, or 0 if error (then error message is also set) */
- KexiDB::Driver* driver(const QString& name);
+ KexiDB::Driver* driver(const TQString& name);
- KexiDB::Driver::Info driverInfo(const QString &name);
+ KexiDB::Driver::Info driverInfo(const TQString &name);
static DriverManagerInternal *self();
@@ -55,9 +56,9 @@ class KEXI_DB_EXPORT DriverManagerInternal : public QObject, public KexiDB::Obje
void aboutDelete( Driver* drv );
protected slots:
/*! Used to destroy all drivers on QApplication quit, so even if there are
DriverManager's static instances that are destroyed on program
- "static destruction", drivers are not kept after QApplication death.
+ "static destruction", drivers are not kept after TQApplication death.
*/
void slotAppQuits();
@@ -73,16 +74,16 @@ class KEXI_DB_EXPORT DriverManagerInternal : public QObject, public KexiDB::Obje
DriverManager::ServicesMap m_services_lcase; //! as above but service names in lowercase
DriverManager::ServicesMap m_services_by_mimetype;
Driver::InfoMap m_driversInfo; //! used to store drivers information
- QAsciiDict<KexiDB::Driver> m_drivers;
+ TQAsciiDict<KexiDB::Driver> m_drivers;
ulong m_refCount;
- QString m_serverErrMsg;
+ TQString m_serverErrMsg;
int m_serverResultNum;
- QString m_serverResultName;
+ TQString m_serverResultName;
//! result names for KParts::ComponentFactory::ComponentLoadingError
- QMap<int,QString> m_componentLoadingErrors;
+ TQMap<int,TQString> m_componentLoadingErrors;
- QStringList possibleProblems;
+ TQStringList possibleProblems;
bool lookupDriversNeeded : 1;
@@ -55,9 +56,9 @@ class KEXI_DB_EXPORT DriverManagerInternal : public QObject, public KexiDB::Obje
void aboutDelete( Driver* drv );
protected slots:
- /*! Used to destroy all drivers on QApplication quit, so even if there are
+ /*! Used to destroy all drivers on TQApplication quit, so even if there are
DriverManager's static instances that are destroyed on program